DEFAULT_GEASE_FILE_NAME = '.gease'
DEFAULT_RELEASE_MESSAGE = "A new release via gease."
NOT_ENOUGH_ARGS = 'Not enough arguments'
KEY_GEASE_USER = 'user'
KEY_GEASE_TOKEN = 'personal_access_token'
MESSAGE_FMT_RELEASED = 'Release is created at: %s'



import os
import json

import gease.exceptions as exceptions
import gease.constants as constants
try:
    FileNotFoundError
except NameError:
    FileNotFoundError = IOError


def get_info(key):
    """
    Find geasefile from user's home folder
    """
    home_dir = os.path.expanduser('~')
    geasefile = os.path.join(home_dir,
                             constants.DEFAULT_GEASE_FILE_NAME)
    try:
        with open(geasefile, 'r') as config:
            gease = json.load(config)
            return gease[key]
    except FileNotFoundError:
        raise exceptions.NoGeaseConfigFound(
            'Cannot find %s' % geasefile)
